import React, { FC } from 'react';
import { VirtualizedListItemsModel } from '../listItemsModels';
import { View, VirtualizedList } from 'react-native';
import { LabelMediumText } from '../../../atoms';
import { styles } from './style';

export const VirtualizedListItemsWrapper: FC<VirtualizedListItemsModel> = ({
  listItemsValues,
  ItemComponent,
  wrapperTitle,
  onClick,
  scrollEnabled= true,
  listKey,
  initialScrollIndex = 0,
}) => {
  return (
    <>
      {ItemComponent && listItemsValues &&
      <VirtualizedList
        listKey={listKey}
        initialScrollIndex={initialScrollIndex}
        scrollEnabled={scrollEnabled}
        data={listItemsValues}
        getItem={(data, index) => data[index]}
        getItemCount={(data) => data.length}
        keyExtractor={(item, index) => index.toString()}
        renderItem={({ item , index }) => {
          if (item) {
            // @ts-ignore
            const RenderComponent = item.Component || ItemComponent;

            // @ts-ignore
            const SetterComponent = <RenderComponent {...item} onClick={onClick} />;
            return (
              <View key={index} style={styles.listItemsWrapperRow}>
                {SetterComponent}
              </View>
            );
          }
          return (
            <View key={index} style={styles.listItemsWrapperRow}>
              <ItemComponent />
            </View>
          );
        }}
        ListHeaderComponent={() => (
          <>
            {wrapperTitle &&
              <View style={styles.listItemsWrapperTitle}>
                <LabelMediumText color={styles.listItemsWrapperTitle.color}>{wrapperTitle}</LabelMediumText>
              </View>
            }
          </>
        )}
      />
      }
    </>
  );
};
